==> box64_0.3.4+dfsg.orig.tar.xz: box64-0.3.4/src/wrapped32/wrappedlibdrm_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error Meh...
#endif

GO(drmAddBufs, iFiiiui)
GO(drmAddContextPrivateMapping, iFiuu)
GO(drmAddContextTag, iFiup)
GO(drmAddMap, iFiuuuup)
GO(drmAgpAcquire, iFi)
//GO(drmAgpAlloc, iFiLLbL_p)
GO(drmAgpBase, LFi)
GO(drmAgpBind, iFiuL)
GO(drmAgpDeviceId, uFi)
GO(drmAgpEnable, iFiL)
GO(drmAgpFree, iFiu)
GO(drmAgpGetMode, LFi)
GO(drmAgpMemoryAvail, LFi)
GO(drmAgpMemoryUsed, LFi)
GO(drmAgpRelease, iFi)
GO(drmAgpSize, LFi)
GO(drmAgpUnbind, iFiu)
GO(drmAgpVendorId, uFi)
GO(drmAgpVersionMajor, iFi)
GO(drmAgpVersionMinor, iFi)
GO(drmAuthMagic, iFiu)
GO(drmAvailable, iFv)
GO(drmCheckModesettingSupported, iFp)
GO(drmClose, iFi)
GO(drmCloseOnce, vFi)
GO(drmCommandNone, iFiL)
GO(drmCommandRead, iFiLpL)
GO(drmCommandWrite, iFiLpL)
GO(drmCommandWriteRead, iFiLpL)
GO(drmCreateContext, iFip)
GO(drmCreateDrawable, iFip)
GO(drmCrtcGetSequence, iFiupp)
GO(drmCrtcQueueSequence, iFiuuUpU)
GO(drmCtlInstHandler, iFii)
GO(drmCtlUninstHandler, iFi)
GO(drmDelContextTag, iFiu)
GO(drmDestroyContext, iFiu)
GO(drmDestroyDrawable, iFiu)
//GO(drmDevicesEqual, 
//GO(drmDMA, iFibuippuiippi_)
GO(drmDropMaster, iFi)
GO(drmError, iFip)
GO(drmFinish, iFiiu)
GO(drmFree, vFp)
GO(drmFreeBufs, iFiip)
GO(drmFreeBusid, vFp)
//GOM(drmFreeDevice, vFEbp_)
//GOM(drmFreeDevices, vFEbp_i)
GO(drmFreeReservedContextList, vFp)
GOM(drmFreeVersion, vFEp)
//GOM(drmGetBufInfo, pFEi)
GO(drmGetBusid, pFi)
GO(drmGetCap, iFiUp)
//GO(drmGetClient, iFiipppbL_bL_)
GO(drmGetContextFlags, iFiup)
GO(drmGetContextPrivateMapping, iFiup)
GO(drmGetContextTag, pFiu)
//GOM(drmGetDevice, iFEibp_)
//GOM(drmGetDevice2, iFEiubp_)
GO(drmGetDeviceNameFromFd, pFi)
GO(drmGetDeviceNameFromFd2, pFi)
//GOM(drmGetDevices, iFEbp_i)
//GOM(drmGetDevices2, iFEubp_i)
//GOM(drmGetEntry, pFEi)
GO(drmGetHashTable, pFv)
GO(drmGetInterruptFromBusID, iFiiii)
//GOM(drmGetLibVersion, pFEi)
GO(drmGetLock, iFiuu)
GO(drmGetMagic, iFip)
GO(drmGetMap, iFiipppppp)
GO(drmGetNodeTypeFromFd, iFi)
GO(drmGetPrimaryDeviceNameFromFd, pFi)
GO(drmGetRenderDeviceNameFromFd, pFi)
GO(drmGetReservedContextList, pFip)
//GO(drmGetStats, 
GOM(drmGetVersion, pFEi)
//GOM(drmHandleEvent, iFEibipppp_)
GO(drmHashCreate, pFv)
GO(drmHashDelete, iFpL)
GO(drmHashDestroy, iFp)
//GO(drmHashFirst, iFpbL_bp_)
GO(drmHashInsert, iFpLp)
//GO(drmHashLookup, iFpLbp_)
//GO(drmHashNext, iFpbL_bp_)
GO(drmIoctl, iFiLp)
GO(drmIsMaster, iFi)
GO(drmMalloc, pFi)
//GO(drmMap, iFiuubp_)
//GOM(drmMapBufs, pFEi)
GO(drmMarkBufs, iFidd)
GO(drmModeAddFB, iFiuuCCuup)
GO(drmModeAddFB2, iFiuuuppppu)
GO(drmModeAddFB2WithModifiers, iFiuuupppppu)
GO(drmModeAtomicAddProperty, iFpuuU)
GO(drmModeAtomicAlloc, pFv)
GO(drmModeAtomicCommit, iFipup)
GO(drmModeAtomicDuplicate, pFp)
GO(drmModeAtomicFree, vFp)
GO(drmModeAtomicGetCursor, iFp)
GO(drmModeAtomicMerge, iFpp)
GO(drmModeAtomicSetCursor, vFpi)
GO(drmModeAttachMode, iFiup)
GO(drmModeConnectorSetProperty, iFiuuU)
GO(drmModeCreateLease, iFipiip)
GO(drmModeCreatePropertyBlob, iFipLp)
GO(drmModeCrtcGetGamma, iFiuuppp)
GO(drmModeCrtcSetGamma, iFiuuppp)
GO(drmModeDestroyPropertyBlob, iFiu)
GO(drmModeDetachMode, iFiup)
GO(drmModeDirtyFB, iFiupu)
//GO(drmModeFreeConnector, vFbuuuuuuuuipippip_)
GO(drmModeFreeCrtc, vFp)
GO(drmModeFreeEncoder, vFp)
GO(drmModeFreeFB, vFp)
GO(drmModeFreeModeInfo, vFp)
//GO(drmModeFreeObjectProperties, vFbupp_)
//GO(drmModeFreePlane, vFbupuuuuuuuuu_)
//GO(drmModeFreePlaneResources, vFbup_)
//GO(drmModeFreeProperty, vFbuuccccccccccccccccccccccccccccccccipipip_)
//GO(drmModeFreePropertyBlob, vFbuup_)
//GO(drmModeFreeResources, vFbipipipipuuuu_)
//GOM(drmModeGetConnector, pFEiu)
//GOM(drmModeGetConnectorCurrent, pFEiu)
GO(drmModeGetCrtc, pFiu)
GO(drmModeGetEncoder, pFiu)
GO(drmModeGetFB, pFiu)
//GO(drmModeGetLease, 
//GOM(drmModeGetPlane, pFEiu)
//GOM(drmModeGetPlaneResources, pFEi)
//GOM(drmModeGetProperty, pFEiu)
//GOM(drmModeGetPropertyBlob, pFEiu)
//GOM(drmModeGetResources, pFEi)
//GO(drmModeListLessees, 
GO(drmModeMoveCursor, iFiuii)
//GOM(drmModeObjectGetProperties, pFEiuu)
GO(drmModeObjectSetProperty, iFiuuuU)
GO(drmModePageFlip, iFiuuup)
GO(drmModePageFlipTarget, iFiuuupu)
GO(drmModeRevokeLease, iFiu)
GO(drmModeRmFB, iFiu)
GO(drmModeSetCrtc, iFiuuuupip)
GO(drmModeSetCursor, iFiuuuu)
GO(drmModeSetCursor2, iFiuuuuii)
GO(drmModeSetPlane, iFiuuuuiiuuuuuu)
//GOM(drmMsg, vFEpV)
GO(drmOpen, iFpp)
GO(drmOpenControl, iFi)
GO(drmOpenOnce, iFppp)
GO(drmOpenOnceWithType, iFppi)
GO(drmOpenRender, iFi)
GO(drmOpenWithType, iFppi)
GO(drmPrimeFDToHandle, iFiip)
GO(drmPrimeHandleToFD, iFiuup)
GO(drmRandom, LFp)
GO(drmRandomCreate, pFL)
GO(drmRandomDestroy, iFp)
GO(drmRandomDouble, dFp)
GO(drmRmMap, iFiu)
GO(drmScatterGatherAlloc, iFiLp)
GO(drmScatterGatherFree, iFiu)
GO(drmSetBusid, iFip)
GO(drmSetClientCap, iFiUU)
GO(drmSetContextFlags, iFiuu)
GO(drmSetInterfaceVersion, iFip)
GO(drmSetMaster, iFi)
//GOM(drmSetServerInfo, vFEbppp_)
GO(drmSLCreate, pFv)
GO(drmSLDelete, iFpL)
GO(drmSLDestroy, iFp)
GO(drmSLDump, vFp)
//GO(drmSLFirst, iFpbL_bp_)
GO(drmSLInsert, iFpLp)
//GO(drmSLLookup, iFpLbp_)
//GO(drmSLLookupNeighbors, iFpLbL_bp_bL_bp_)
//GO(drmSLNext, iFpbL_bp_)
GO(drmSwitchToContext, iFiu)
GO(drmSyncobjCreate, iFiup)
GO(drmSyncobjDestroy, iFiu)
GO(drmSyncobjExportSyncFile, iFiup)
GO(drmSyncobjFDToHandle, iFiip)
GO(drmSyncobjHandleToFD, iFiup)
GO(drmSyncobjImportSyncFile, iFiui)
GO(drmSyncobjQuery, iFippu)
GO(drmSyncobjQuery2, iFippuu)
GO(drmSyncobjReset, iFipu)
GO(drmSyncobjSignal, iFipu)
GO(drmSyncobjTimelineSignal, iFippu)
GO(drmSyncobjTimelineWait, iFippuIup)
GO(drmSyncobjTransfer, iFiuUuUu)
GO(drmSyncobjWait, iFipuIup)
GO(drmUnlock, iFiu)
GO(drmUnmap, iFpu)
//GOM(drmUnmapBufs, iFEbip_)
GO(drmUpdateDrawableInfo, iFiuuup)
//GO(drmWaitVBlank,

==> box64_0.3.8+dfsg.orig.tar.xz: box64-0.3.8/src/wrapped32/wrappedlibdrm_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error Meh...
#endif

GO(drmAddBufs, iFiiiui)
GO(drmAddContextPrivateMapping, iFiuu)
GO(drmAddContextTag, iFiup)
GO(drmAddMap, iFiuuuup)
GO(drmAgpAcquire, iFi)
//GO(drmAgpAlloc, iFiLLbL_p)
GO(drmAgpBase, LFi)
GO(drmAgpBind, iFiuL)
GO(drmAgpDeviceId, uFi)
GO(drmAgpEnable, iFiL)
GO(drmAgpFree, iFiu)
GO(drmAgpGetMode, LFi)
GO(drmAgpMemoryAvail, LFi)
GO(drmAgpMemoryUsed, LFi)
GO(drmAgpRelease, iFi)
GO(drmAgpSize, LFi)
GO(drmAgpUnbind, iFiu)
GO(drmAgpVendorId, uFi)
GO(drmAgpVersionMajor, iFi)
GO(drmAgpVersionMinor, iFi)
GO(drmAuthMagic, iFiu)
GO(drmAvailable, iFv)
GO(drmCheckModesettingSupported, iFp)
GO(drmClose, iFi)
GO(drmCloseOnce, vFi)
GO(drmCommandNone, iFiL)
GO(drmCommandRead, iFiLpL)
GO(drmCommandWrite, iFiLpL)
GO(drmCommandWriteRead, iFiLpL)
GO(drmCreateContext, iFip)
GO(drmCreateDrawable, iFip)
GO(drmCrtcGetSequence, iFiupp)
GO(drmCrtcQueueSequence, iFiuuUpU)
GO(drmCtlInstHandler, iFii)
GO(drmCtlUninstHandler, iFi)
GO(drmDelContextTag, iFiu)
GO(drmDestroyContext, iFiu)
GO(drmDestroyDrawable, iFiu)
//GO(drmDevicesEqual, 
//GO(drmDMA, iFibuippuiippi_)
GO(drmDropMaster, iFi)
GO(drmError, iFip)
GO(drmFinish, iFiiu)
GO(drmFree, vFp)
GO(drmFreeBufs, iFiip)
GO(drmFreeBusid, vFp)
//GOM(drmFreeDevice, vFEbp_)
//GOM(drmFreeDevices, vFEbp_i)
GO(drmFreeReservedContextList, vFp)
GOM(drmFreeVersion, vFEp)
//GOM(drmGetBufInfo, pFEi)
GO(drmGetBusid, pFi)
GO(drmGetCap, iFiUp)
//GO(drmGetClient, iFiipppbL_bL_)
GO(drmGetContextFlags, iFiup)
GO(drmGetContextPrivateMapping, iFiup)
GO(drmGetContextTag, pFiu)
//GOM(drmGetDevice, iFEibp_)
//GOM(drmGetDevice2, iFEiubp_)
GO(drmGetDeviceNameFromFd, pFi)
GO(drmGetDeviceNameFromFd2, pFi)
//GOM(drmGetDevices, iFEbp_i)
//GOM(drmGetDevices2, iFEubp_i)
//GOM(drmGetEntry, pFEi)
GO(drmGetHashTable, pFv)
GO(drmGetInterruptFromBusID, iFiiii)
//GOM(drmGetLibVersion, pFEi)
GO(drmGetLock, iFiuu)
GO(drmGetMagic, iFip)
GO(drmGetMap, iFiipppppp)
GO(drmGetNodeTypeFromFd, iFi)
GO(drmGetPrimaryDeviceNameFromFd, pFi)
GO(drmGetRenderDeviceNameFromFd, pFi)
GO(drmGetReservedContextList, pFip)
//GO(drmGetStats, 
GOM(drmGetVersion, pFEi)
GOM(drmHandleEvent, iFEip)
GO(drmHashCreate, pFv)
GO(drmHashDelete, iFpL)
GO(drmHashDestroy, iFp)
//GO(drmHashFirst, iFpbL_bp_)
GO(drmHashInsert, iFpLp)
//GO(drmHashLookup, iFpLbp_)
//GO(drmHashNext, iFpbL_bp_)
GO(drmIoctl, iFiLp)
GO(drmIsMaster, iFi)
GO(drmMalloc, pFi)
//GO(drmMap, iFiuubp_)
//GOM(drmMapBufs, pFEi)
GO(drmMarkBufs, iFidd)
GO(drmModeAddFB, iFiuuCCuup)
GO(drmModeAddFB2, iFiuuuppppu)
GO(drmModeAddFB2WithModifiers, iFiuuupppppu)
GO(drmModeAtomicAddProperty, iFpuuU)
GO(drmModeAtomicAlloc, pFv)
GO(drmModeAtomicCommit, iFipup)
GO(drmModeAtomicDuplicate, pFp)
GO(drmModeAtomicFree, vFp)
GO(drmModeAtomicGetCursor, iFp)
GO(drmModeAtomicMerge, iFpp)
GO(drmModeAtomicSetCursor, vFpi)
GO(drmModeAttachMode, iFiup)
GO(drmModeConnectorSetProperty, iFiuuU)
GO(drmModeCreateLease, iFipiip)
GO(drmModeCreatePropertyBlob, iFipLp)
GO(drmModeCrtcGetGamma, iFiuuppp)
GO(drmModeCrtcSetGamma, iFiuuppp)
GO(drmModeDestroyPropertyBlob, iFiu)
GO(drmModeDetachMode, iFiup)
GO(drmModeDirtyFB, iFiupu)
GOM(drmModeFreeConnector, vFEp)
GO(drmModeFreeCrtc, vFp)
GO(drmModeFreeEncoder, vFp)
GO(drmModeFreeFB, vFp)
GO(drmModeFreeModeInfo, vFp)
//GO(drmModeFreeObjectProperties, vFbupp_)
//GO(drmModeFreePlane, vFbupuuuuuuuuu_)
//GO(drmModeFreePlaneResources, vFbup_)
//GO(drmModeFreeProperty, vFbuuccccccccccccccccccccccccccccccccipipip_)
//GO(drmModeFreePropertyBlob, vFbuup_)
GOM(drmModeFreeResources, vFEp)
GOM(drmModeGetConnector, pFEiu)
GOM(drmModeGetConnectorCurrent, pFEiu)
GO(drmModeGetCrtc, pFiu)
GO(drmModeGetEncoder, pFiu)
GO(drmModeGetFB, pFiu)
//GO(drmModeGetLease, 
//GOM(drmModeGetPlane, pFEiu)
//GOM(drmModeGetPlaneResources, pFEi)
//GOM(drmModeGetProperty, pFEiu)
//GOM(drmModeGetPropertyBlob, pFEiu)
GOM(drmModeGetResources, pFEi)
//GO(drmModeListLessees, 
GO(drmModeMoveCursor, iFiuii)
//GOM(drmModeObjectGetProperties, pFEiuu)
GO(drmModeObjectSetProperty, iFiuuuU)
GO(drmModePageFlip, iFiuuup)
GO(drmModePageFlipTarget, iFiuuupu)
GO(drmModeRevokeLease, iFiu)
GO(drmModeRmFB, iFiu)
GO(drmModeSetCrtc, iFiuuuupip)
GO(drmModeSetCursor, iFiuuuu)
GO(drmModeSetCursor2, iFiuuuuii)
GO(drmModeSetPlane, iFiuuuuiiuuuuuu)
//GOM(drmMsg, vFEpV)
GO(drmOpen, iFpp)
GO(drmOpenControl, iFi)
GO(drmOpenOnce, iFppp)
GO(drmOpenOnceWithType, iFppi)
GO(drmOpenRender, iFi)
GO(drmOpenWithType, iFppi)
GO(drmPrimeFDToHandle, iFiip)
GO(drmPrimeHandleToFD, iFiuup)
GO(drmRandom, LFp)
GO(drmRandomCreate, pFL)
GO(drmRandomDestroy, iFp)
GO(drmRandomDouble, dFp)
GO(drmRmMap, iFiu)
GO(drmScatterGatherAlloc, iFiLp)
GO(drmScatterGatherFree, iFiu)
GO(drmSetBusid, iFip)
GO(drmSetClientCap, iFiUU)
GO(drmSetContextFlags, iFiuu)
GO(drmSetInterfaceVersion, iFip)
GO(drmSetMaster, iFi)
//GOM(drmSetServerInfo, vFEbppp_)
GO(drmSLCreate, pFv)
GO(drmSLDelete, iFpL)
GO(drmSLDestroy, iFp)
GO(drmSLDump, vFp)
//GO(drmSLFirst, iFpbL_bp_)
GO(drmSLInsert, iFpLp)
//GO(drmSLLookup, iFpLbp_)
//GO(drmSLLookupNeighbors, iFpLbL_bp_bL_bp_)
//GO(drmSLNext, iFpbL_bp_)
GO(drmSwitchToContext, iFiu)
GO(drmSyncobjCreate, iFiup)
GO(drmSyncobjDestroy, iFiu)
GO(drmSyncobjExportSyncFile, iFiup)
GO(drmSyncobjFDToHandle, iFiip)
GO(drmSyncobjHandleToFD, iFiup)
GO(drmSyncobjImportSyncFile, iFiui)
GO(drmSyncobjQuery, iFippu)
GO(drmSyncobjQuery2, iFippuu)
GO(drmSyncobjReset, iFipu)
GO(drmSyncobjSignal, iFipu)
GO(drmSyncobjTimelineSignal, iFippu)
GO(drmSyncobjTimelineWait, iFippuIup)
GO(drmSyncobjTransfer, iFiuUuUu)
GO(drmSyncobjWait, iFipuIup)
GO(drmUnlock, iFiu)
GO(drmUnmap, iFpu)
//GOM(drmUnmapBufs, iFEbip_)
GO(drmUpdateDrawableInfo, iFiuuup)
//GO(drmWaitVBlank,
